@@ -5,15 +5,14 @@ from .util import struct_util
 from .util import seq_util
 from . import external_functions
 
-
 RESERVED_COL = ["chrom", "spos", "epos", "ensgid"]
 
 
 def is_available(field):
     flag = True
-    if struct_util.get_dict_value(field, "is_available", True) == False:
+    if struct_util.get_dict_value(field, "is_available", True) is False:
         flag = False
-    if struct_util.get_dict_value(field, "do_import", True) == False:
+    if struct_util.get_dict_value(field, "do_import", True) is False:
         flag = False
     return flag
 
@@ -104,7 +103,7 @@ class GeneSourceReader():
             if is_available(f1):
                 self.field_names.append(f1['name'])
 
-                # print("self.header",self.header, f1['name'], self.key_colidx)
+                # print("self.header", self.header, f1['name'], self.key_colidx)
                 colidx = self.header.index(f1['name'])
                 if f1['name'] in self.header:
                     if is_reserved_column(f1):
@@ -135,7 +134,6 @@ class GeneSourceReader():
 
                 name2_map[colidx] = struct_util.get_dict_value(f1, 'name2', '')
 
-
         if 'ensgid' in self.reserved_colidx.keys():
             self.key_colidx = self.reserved_colidx['ensgid']
 
@@ -148,12 +146,11 @@ class GeneSourceReader():
             else:
                 self.target_colnames2.append(name2_map[tidx])
 
-
     def rm_version_in_ensgid(self, ensg):
         return ensg.strip().split('.')[0]
 
-
     def get_value_using_eval_field_function(self, colidx, cidx_no, cidxvalue):
+        external_functions.void()
         exec_str = "external_functions." + self.field_function[colidx]
         exec_str += '('
         paramstr_list = []
@@ -180,16 +177,16 @@ class GeneSourceReader():
                 try:
                     rst_value = int(value)
                 except ValueError:
-                    print('ValueError:',value)
+                    print('ValueError:', value)
                 rst_value = int(value)
             elif value_type == 'number':
                 try:
                     rst_value = float(value)
                 except ValueError:
-                    print('ValueError:',value)
+                    print('ValueError:', value)
                 rst_value = float(value)
             elif value_type == 'boolean':
-                rst_value = boolean(value)
+                rst_value = bool(value)
             else:
                 rst_value = value
         return rst_value
@@ -219,7 +216,7 @@ class GeneSourceReader():
 
                     if colidx in self.field_function.keys():
                         cidxvalue = self.get_value_using_eval_field_function(colidx, cidx_no, cidxvalue)
-                        
+
                     delimiter = ''
                     if colidx in self.delimiter.keys():
                         delimiter = self.delimiter[colidx]
@@ -231,7 +228,6 @@ class GeneSourceReader():
                     else:
                         target_data.append(self.typecast(cidxvalue, self.field_type[colidx]))
 
-
                 self.data[ensgid].append(target_data)
 
                 for resv in self.reserved_colidx.keys():
@@ -247,8 +243,8 @@ class GeneSourceReader():
                         if resv == 'ensgid':
                             self.reserved_data[resv][ensgid] = self.rm_version_in_ensgid(arr[colidx])
                         else:
-                            self.reserved_data[resv][ensgid] = self.typecast(strip_value(arr[colidx])
-                                , self.field_type[colidx])
+                            self.reserved_data[resv][ensgid] = self.typecast(
+                                strip_value(arr[colidx]), self.field_type[colidx])
 
     def load_range_data(self):
         for line in file_util.gzopen(self.fname):
@@ -304,14 +300,14 @@ class GeneSourceReader():
                 datalist = self.data[ensgid]
             except KeyError:
                 datalist = []
-    
+
         if self.is_range_data and len(self.target_colnames) == 1:
             # for special case (CYTOBAND)
             d = []
             for datarow in datalist:
                 d.append(datarow[0])
             if not self.is_empty_value(d):
-                rstdata.append({self.target_colnames[0]:d})
+                rstdata.append({self.target_colnames[0]: d})
         else:
             for datarow in datalist:
                 d = {}
@@ -320,7 +316,7 @@ class GeneSourceReader():
                         k1 = self.target_colnames2[k]
                     else:
                         k1 = self.target_colnames[k]
-                    if not self.is_empty_value(datarow[k]) and datarow[k] != None:
+                    if not self.is_empty_value(datarow[k]) and datarow[k] is not None:
                         d[k1] = datarow[k]
                 rstdata.append(d)
 
@@ -346,8 +342,6 @@ class GeneSourceMerger():
                     ensgid_map[ensgid] = 1
         self.ensgid_list = list(ensgid_map.keys())
 
-    
-
     def set_colnames(self):
         self.colnames = {}
         self.colnames2 = {}
@@ -369,7 +363,6 @@ class GeneSourceMerger():
                     v1 = ''
                 data[r1] = v1
 
-
             for sid in self.source_readers.keys():
                 s1 = self.source_readers[sid]
 
@@ -381,7 +374,7 @@ class GeneSourceMerger():
                         data.update(d1[0])
                 else:
                     if len(d1) > 0:
-                        data.update({s1.subembedded:d1})
+                        data.update({s1.subembedded: d1})
         return data
 
     def get_reserved_data(self, ensgid):
@@ -423,19 +416,18 @@ class GeneSourceMerger():
                     except KeyError:
                         for cidx in s1.target_colidx:
                             data.append('')
-        print('get_data_list',data)
+        print('get_data_list', data)
         return data
 
 
 class GeneDataSourceFile():
     def __init__(self, opt):
-        self.vartype = opt['vartype']
-        self.outtype = opt['outtype']
-        self.set_outfile_extension(opt['out'], opt['outtype'])
-        self.datastruct = file_util.load_json(opt['ds'])
-        self.region = opt['region']
-        self.blocksize = opt['blocksize']
-        
+        self.vartype = opt.vartype
+        self.outtype = opt.outtype
+        self.set_outfile_extension(opt.out, opt.outtype)
+        self.datastruct = file_util.load_json(opt.ds)
+        self.region = opt.region
+        self.blocksize = opt.blocksize
 
     def set_outfile_extension(self, out, outtype):
         out2 = out.replace('.'+outtype+'.gz', '.' + outtype)
@@ -465,12 +457,11 @@ class GeneDataSourceFile():
         header.append('\t'.join(info_arr))
         return '#' + '\t'.join(header)
 
-    def save_json_out(self):
+    def save_json_out(self, data):
         # with open(self.out, 'w') as fp:
         fp = open(self.out, 'w')
         json.dump(data, fp)
 
-
     def save_file_header(self, fp):
         if self.outtype == "json":
             fp.write('[')
@@ -480,7 +471,7 @@ class GeneDataSourceFile():
             fp.write(']')
 
     def save_file_record(self, fp, data, prev_flag):
-        
+
         if self.outtype == "json":
             flag = True
             if "CODING_GENE" in self.vartype:
@@ -499,10 +490,9 @@ class GeneDataSourceFile():
             fp.write(data)
         return flag
 
-
     # init function
     def make_single_source_file(self):
-        file_util.check_dir(self.out)        
+        file_util.check_dir(self.out)
         fp = open(self.out, 'w')
         # fp.write(self.get_bed_header() + '\n')
 
@@ -528,6 +518,7 @@ class GeneDataSourceFile():
             # line = '\t'.join(data)
             data = gsm.get_data_dict(ensgid)
             if len(data.keys()) > 0:
+
                 flag2 = self.save_file_record(fp, data, flag_write)
                 if flag2:
                     flag_write = True
@@ -540,10 +531,7 @@ class GeneDataSourceFile():
         print('Saved', self.out)
         fp.close()
 
-        ### file check
+        # file check
         print('Json checking...', self.out)
         fp = open(self.out)
         data = json.load(fp)
-
-
-
